@@ -1,7 +1,11 @@
-from Products.Five import BrowserView
-from collective.gallery import interfaces
+from zope import component
 from zope import interface
-from Products.CMFCore.utils import getToolByName
+from Products.Five import BrowserView
+
+from plone.registry.interfaces import IRegistry
+
+from collective.gallery import interfaces
+
 
 class BaseBrowserView(BrowserView):
     """This code is the base code of gallery views.
@@ -15,14 +19,15 @@ class BaseBrowserView(BrowserView):
     def __init__(self, context, request):
         self.context = context
         self.request = request
+        self._settings = None
 
     @property
     def width(self):
-        return self.settings().getProperty('photo_max_size', 400)
+        return self.settings().photo_max_size
 
     @property
     def height(self):
-        return self.settings().getProperty('photo_max_size', 400)
+        return self.settings().photo_max_size
 
     @property
     def id(self):
@@ -35,7 +40,7 @@ class BaseBrowserView(BrowserView):
     @property
     def creator(self):
         return self.context.Creators()[0]
-    
+
     @property
     def description(self):
         return self.context.Description()
@@ -43,9 +48,27 @@ class BaseBrowserView(BrowserView):
     @property
     def date(self):
         return self.context.Date()
-    
+
     def settings(self):
-        return getToolByName(self.context, 'portal_properties').gallery_properties
+        if self._settings is None:
+            registry = component.getUtility(IRegistry)
+            self._settings = registry.forInterface(interfaces.IGallerySettings)
+        return self._settings
 
     def photos(self):
         return []
+
+    def get_photo(self, index=0):
+        photos = self.photos()
+
+        if len(photos) == 0:
+            return {'url': '',
+                    'title': u'',
+                    'description': u'',
+                    'thumb_url': ''}
+
+        if index > len(self.photos()):
+            if index != 0:
+                index = 0
+
+        return photos[index]
